@@ -73,7 +73,7 @@ static void csync_exclude_expand_escapes(QByteArray &input)
             line[o++] = line[i];
         }
     }
-    input.resize(o);
+    input.resize(OCC::Utility::convertSizeToUint(o));
 }
 
 // See http://support.microsoft.com/kb/74496 and
@@ -133,7 +133,7 @@ bool csync_is_windows_reserved_word(const char *filename)
 
 static CSYNC_EXCLUDE_TYPE _csync_excluded_common(const char *path, bool excludeConflictFiles)
 {
-    const char *bname = NULL;
+    const char *bname = nullptr;
     size_t blen = 0;
     int rc = -1;
     CSYNC_EXCLUDE_TYPE match = CSYNC_NOT_EXCLUDED;
@@ -261,9 +261,7 @@ ExcludedFiles::ExcludedFiles(QString localPath)
         addInTreeExcludeFilePath(fi.absoluteFilePath());
 }
 
-ExcludedFiles::~ExcludedFiles()
-{
-}
+ExcludedFiles::~ExcludedFiles() = default;
 
 void ExcludedFiles::addExcludeFilePath(const QString &path)
 {
@@ -288,7 +286,11 @@ void ExcludedFiles::addManualExclude(const QByteArray &expr)
 
 void ExcludedFiles::addManualExclude(const QByteArray &expr, const QByteArray &basePath)
 {
+#if defined(Q_OS_WIN)
+    Q_ASSERT(basePath.size() >= 2 && basePath.at(1) == ':');
+#else
     Q_ASSERT(basePath.startsWith('/'));
+#endif
     Q_ASSERT(basePath.endsWith('/'));
 
     auto key = basePath;
@@ -322,7 +324,11 @@ bool ExcludedFiles::loadExcludeFile(const QByteArray & basePath, const QString &
         csync_exclude_expand_escapes(line);
         _allExcludes[basePath].append(line);
     }
-    prepare(basePath);
+
+    // nothing to prepare if the user decided to not exclude anything
+    if(_allExcludes.size())
+        prepare(basePath);
+
     return true;
 }
 
@@ -338,8 +344,9 @@ bool ExcludedFiles::reloadExcludeFiles()
     _fullRegexDir.clear();
 
     bool success = true;
-    for (auto basePath : _excludeFiles.keys()) {
-        for (auto file : _excludeFiles.value(basePath)) {
+    const auto keys = _excludeFiles.keys();
+    for (const auto& basePath : keys) {
+        for (const auto& file : _excludeFiles.value(basePath)) {
             success = loadExcludeFile(basePath, file);
         }
     }
@@ -659,7 +666,8 @@ void ExcludedFiles::prepare()
     _fullRegexFile.clear();
     _fullRegexDir.clear();
 
-    for (auto const & basePath : _allExcludes.keys())
+    const auto keys = _allExcludes.keys();
+    for (auto const & basePath : keys)
         prepare(basePath);
 }
 
